Moccasin - MetaMask UI

# Moccasin - MetaMask Interaction

Connecting to MetaMask...

Heads Up: You might need to open your MetaMask extension (check for a pop-up or the fox icon) to confirm or reject transactions initiated by Moccasin.

If you close this tab or the MetaMask connection is lost, the Moccasin CLI operation may time out.

Tips: If MetaMask pop-up doesn't appear or you encounter issues, please check their user guide for troubleshooting.